==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/PatchOptionsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PatchOptionsFluent<A extends PatchOptionsFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToDryRun(int index,String item);
    public A setToDryRun(int index,String item);
    public A addToDryRun(String... items);
    public A addAllToDryRun(Collection<String> items);
    public A removeFromDryRun(String... items);
    public A removeAllFromDryRun(Collection<String> items);
    public List<String> getDryRun();
    public String getDryRun(int index);
    public String getFirstDryRun();
    public String getLastDryRun();
    public String getMatchingDryRun(Predicate<String> predicate);
    public Boolean hasMatchingDryRun(Predicate<String> predicate);
    public A withDryRun(List<String> dryRun);
    public A withDryRun(String... dryRun);
    public Boolean hasDryRun();
    public A addNewDryRun(StringBuilder arg1);
    public A addNewDryRun(int[] arg1,int arg2,int arg3);
    public A addNewDryRun(char[] arg1);
    public A addNewDryRun(StringBuffer arg1);
    public A addNewDryRun(byte[] arg1,int arg2);
    public A addNewDryRun(byte[] arg1);
    public A addNewDryRun(char[] arg1,int arg2,int arg3);
    public A addNewDryRun(byte[] arg1,int arg2,int arg3);
    public A addNewDryRun(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewDryRun(String arg1);
    public String getFieldManager();
    public A withFieldManager(String fieldManager);
    public Boolean hasFieldManager();
    public A withNewFieldManager(StringBuilder arg1);
    public A withNewFieldManager(int[] arg1,int arg2,int arg3);
    public A withNewFieldManager(char[] arg1);
    public A withNewFieldManager(StringBuffer arg1);
    public A withNewFieldManager(byte[] arg1,int arg2);
    public A withNewFieldManager(byte[] arg1);
    public A withNewFieldManager(char[] arg1,int arg2,int arg3);
    public A withNewFieldManager(byte[] arg1,int arg2,int arg3);
    public A withNewFieldManager(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFieldManager(String arg1);
    public Boolean getForce();
    public A withForce(Boolean force);
    public Boolean hasForce();
    public A withNewForce(String arg1);
    public A withNewForce(boolean arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
}

==> kubernetes-model-core-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/PatchOptionsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PatchOptionsFluent<A extends PatchOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToDryRun(int index,String item);
    public A setToDryRun(int index,String item);
    public A addToDryRun(String... items);
    public A addAllToDryRun(Collection<String> items);
    public A removeFromDryRun(String... items);
    public A removeAllFromDryRun(Collection<String> items);
    public List<String> getDryRun();
    public String getDryRun(int index);
    public String getFirstDryRun();
    public String getLastDryRun();
    public String getMatchingDryRun(Predicate<String> predicate);
    public Boolean hasMatchingDryRun(Predicate<String> predicate);
    public A withDryRun(List<String> dryRun);
    public A withDryRun(String... dryRun);
    public Boolean hasDryRun();
    public A addNewDryRun(StringBuilder arg1);
    public A addNewDryRun(int[] arg1,int arg2,int arg3);
    public A addNewDryRun(char[] arg1);
    public A addNewDryRun(StringBuffer arg1);
    public A addNewDryRun(byte[] arg1,int arg2);
    public A addNewDryRun(byte[] arg1);
    public A addNewDryRun(char[] arg1,int arg2,int arg3);
    public A addNewDryRun(byte[] arg1,int arg2,int arg3);
    public A addNewDryRun(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewDryRun(String arg1);
    public String getFieldManager();
    public A withFieldManager(String fieldManager);
    public Boolean hasFieldManager();
    public A withNewFieldManager(StringBuilder arg1);
    public A withNewFieldManager(int[] arg1,int arg2,int arg3);
    public A withNewFieldManager(char[] arg1);
    public A withNewFieldManager(StringBuffer arg1);
    public A withNewFieldManager(byte[] arg1,int arg2);
    public A withNewFieldManager(byte[] arg1);
    public A withNewFieldManager(char[] arg1,int arg2,int arg3);
    public A withNewFieldManager(byte[] arg1,int arg2,int arg3);
    public A withNewFieldManager(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFieldManager(String arg1);
    public Boolean getForce();
    public A withForce(Boolean force);
    public Boolean hasForce();
    public A withNewForce(String arg1);
    public A withNewForce(boolean arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
}
